﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Install the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Install language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}
# SIG # Begin signature block
# MIIpKAYJKoZIhvcNAQcCoIIpGTCCKRUCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCCh1voBODYpfCet
# zwmmor0XvG3ngI9/l8E/7NCzPBjyWaCCDfQwggZyMIIEWqADAgECAhMzAAAEPxXT
# o2me74nMAAAAAAQ/MA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjQxMTE5MTk1MDU4WhcNMjUxMTEyMTk1MDU4WjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAqsr+k9yh9dU/cF9B1Ko8
# T6SaoJNg9kJYh809q0GBZq1WrDbRGcgAClcMmMtAFgIps7Fimyyw/ympDR2Zila5
# iDwHRPpPefdumtlFE2iLDgoZHDXoOs2DdZZza5tYKaA8rmq8vmIh6JfvXHqtlWJd
# s6hAxzHrimvJHUF+Kq5T8n8bRbzOUHbfrvvIYDlQ5YXu1tCFU9mEcVe0y+A3VgsZ
# gEobuJ8UB64Snm0P3eJRNYMELzuNZuwRK+X3VF87u4VRM7t18/csk7ANACbO8/nC
# tT5NzsAdobodUQoSevvY8b474GO9QdMFjXN6PF7oxGq0fT617VN0Nizkl4qAVa9c
# qBhplDelQ20xjzOnFTpHhp9j7/9neYBYkonH9EnLWkIHfCQ7NlDT6vSVyD/tswb9
# jQK7jj5klCrPx9UL3/T7zWCBGbNGp7ylExVt4crtI42CVGC7YpH/IEO2CeCszVVy
# HslZxycPBmRRGBzvLwodkYTl9HnsDMVjnlucqsbWNeqdAgMBAAGjggGCMIIBfjAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQULPGeoivj
# /NcRbrh1VDqlXOI1df0wVAYDVR0RBE0wS6RJMEcxLTArBgNVBAsTJE1pY3Jvc29m
# dCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRlZDEWMBQGA1UEBRMNNDY0MjIzKzUw
# MzM5MjAfBgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBL
# MEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWND
# b2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggr
# BgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9N
# aWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJ
# KoZIhvcNAQEMBQADggIBAKiH9gTsKkb1QsFOWaiSF1sUpJ/aboTO7pn5eafSaeup
# pt9KVvZaZbZOonaTWyfR9k4M/WPBsyRaIQRDvEhlB1JCcSHUe3TxFdYMyA0ZLLGV
# uUahdJ7KiNo0HrFtQbhtIo/SwcoezS06kShkDx4/PMlSdsp/woebzjuab7sgvSXy
# sX97vj1ZQlESvgldF2wAg5+C0wKCLdB43/H08gq53PcZQ2s5qDvqluZ0tFjNmPEH
# Kh+kaG+xTZCRJQGf/mrTmBlRtKcL293EXNtEO344ybYNoCO7snEI5Ine3vjJgd66
# J7HJqrSYPiKjEZ1KH85n8A6ivR4LlsL87gqrr41NPR6mN3KA3lqWd2jpnS0I7T8W
# Nqk1k9aQQlXHQ8V+TRwvXdDlh5OdIEQ/xrR21yV+lDGjkWsyjeX2UgOg0wFDcX90
# PVPGXP8DPvZb04P38npzWrfKwmyQC3gCA91dfXOg6g9AmUJKZvQbdcEcoZhLw9dt
# 6MM2149eeaz6QIprT6marM21TGXp40N/v/5MXeAk/7LySCHUJWiaIt9lfyOtKdDT
# hSNPFTuXcINaDJOBcY21ranmTsLd/3FKw+Z5UpvxHA83W0qRBq6t5I/C5AKrQZho
# mPyA7QyVsDHs3ekXXZQ11v203ACerQ2KnquSR7gE25yfcz3vF1VV4IA/7HKts8dy
# MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9z
# b2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1
# OTA5WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
# aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
# cnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAy
# MDExMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqC
# EE00uvK2WCGfQhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC
# 04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlIm
# Ei/nqwhQz7NEt13YxC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPe
# Bw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb
# 2T6xjF3oiU+EGvKhL1nkkDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
# OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yx
# kq4cI6epZuxhH2rhKEmdX4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA
# 4bysAoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uD
# jexNSTCnq47f7Fufr/zdsGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ec
# XL93KCjx7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4Ta
# sIgX3p5O9JawvEagbJjS4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQD
# AgEAMB0GA1UdDgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIE
# DB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNV
# HSMEGDAWgBRyLToCMZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklo
# dHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
# BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQB
# gjcuAzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
# aW9wcy9kb2NzL3ByaW1hcnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBn
# AGEAbABfAHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqG
# SIb3DQEBCwUAA4ICAQBn8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8u
# LD74w3LRbYP+vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxC
# i1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQ
# u6SpBQyb7Wj6aC6VoCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n
# 7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVY
# ODJxJxp/sfQn+N4sOiBpmLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
# bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3
# BtEGsXUfFL5hYbXw3MYbBL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmA
# H9AAKcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5
# GEv/1rMjaHXmr/r8i+sLgOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF6
# 70EKsT/7qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGC
# GoowghqGAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
# MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
# b24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMA
# AAQ/FdOjaZ7vicwAAAAABD8wDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcNAQkD
# MQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJ
# KoZIhvcNAQkEMSIEILHG5OyijfDOM5bxiJFmyVasy7d752HLA4qfvHm7QzF9MEIG
# CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBvAGYAdKEagBhodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20wDQYJKoZIhvcNAQEBBQAEggGAW7sK06EnoGre+UOU
# VXokVIiEGOwtPx9ip4E8yAXmn9ANm+B4dp7cl/tLGtfKdDCSnBGk2M4jJvrIL+HQ
# RZVZQkKjaHF/nHAEQ93h9Yne3X6/8EKFsLaISKI+zhxgoTsUluhAsnEBt9Aphabf
# CJ8i9jriMpljj7o8S4+upbXkqJVqpWLNvy3YhyaCALvPNajyHE6U+sNhSjuL6WXD
# OPrNQHnDgVlz8PpVnqktsOYDE+mBUh88Kxnb7b3JPawvG59TZqnqbl4lFDOqRRXq
# L1rPA2j7xJRmzCeUAf+h0eRWM5Qtkjr8OJYTD77WxgLnEdLrOCxd8NP4oAKaTHtM
# JhPBed7INeyfvVBoXOWzv36RTXQIR8dj6iMog8auwv127o+joyqSg1+LuHrVwyHJ
# VnIMCBoFzpDAX8EfEFV5WPMcq8viRX2GOyPqY47Gaf7tXI7ux0le31uyanboETx0
# qR1aL911zhU9AOGNszckm82Ns1RYI/+s6YHKY/lYhHyyt8ghoYIXlDCCF5AGCisG
# AQQBgjcDAwExgheAMIIXfAYJKoZIhvcNAQcCoIIXbTCCF2kCAQMxDzANBglghkgB
# ZQMEAgEFADCCAVIGCyqGSIb3DQEJEAEEoIIBQQSCAT0wggE5AgEBBgorBgEEAYRZ
# CgMBMDEwDQYJYIZIAWUDBAIBBQAEID/ZOa9KgmdOWHgTBEV8lYHeihdv+oPMW8XF
# VC1rVD8xAgZoJeAH14sYEzIwMjUwNTI4MDMzNzExLjQ2NFowBIACAfSggdGkgc4w
# gcsxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
# ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJTAjBgNVBAsT
# HE1pY3Jvc29mdCBBbWVyaWNhIE9wZXJhdGlvbnMxJzAlBgNVBAsTHm5TaGllbGQg
# VFNTIEVTTjpBOTM1LTAzRTAtRDk0NzElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUt
# U3RhbXAgU2VydmljZaCCEeowggcgMIIFCKADAgECAhMzAAACDLlk4zWc7PSuAAEA
# AAIMMA0GCSqGSIb3DQEBCwUAMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
# aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
# cG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEw
# MB4XDTI1MDEzMDE5NDMwMFoXDTI2MDQyMjE5NDMwMFowgcsxCzAJBgNVBAYTAlVT
# MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
# ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVy
# aWNhIE9wZXJhdGlvbnMxJzAlBgNVBAsTHm5TaGllbGQgVFNTIEVTTjpBOTM1LTAz
# RTAtRDk0NzElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZTCC
# AiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAMoBViY95G2Br9TqPOrKosPQ
# wCiiXbeBwE3nz5n9eyRjA0mxn477BXJBiXx09MrX8ELbECJzWb4m9ySqNVpDfYqZ
# RGwRmi2KtBjg8pVb55fBG3evqzOAu6JzqqgeVtejH+XQcm2BRGTMNdYyQqYZIvvP
# z9yupy+Ziq/y3+yUAXgn6anNv20wVWaPApc41V1HCD1DdZo9kELta+iLs9Eg3aOC
# NIGcdjIBlKWy0o2ulhvr4a7qhIWRDMalHrn5A0N2Q/i585/g9s6Dd9vi4Y+MjwQ8
# qWnAzBqLWRDJf5+ByAKhX0n6jwxhgJlR63eTOGHBHOqHosx4ONpcs/vTVJdeJdzZ
# kfO4MdtL+xm0nfrbtxWkKVcQhS+DbGmvSs+Ui0fC2OjU/AwKldiqdgq9fxonydrB
# P1bwVS67Jk8bXznb6riORWV4ovvH7t6XwRN6Ft2TB2EBfJeKZoTNZ6001KYb8p8c
# Cn1zPCwvW8qvhGCf6kgiRke6iZ1/l7jzUr7EhaEsI92m5XzsSoY4r+NuE6dkSrB2
# 8DQCUxot+yYJ6Zma6l6Npi4STTn/pwJTGAXjMKeQl5h0wA/71niRWHu3NEWzD+Vl
# KXYPsSEgDoqePpF98faTti1IZK/zoJKHN+JdrP3LqxO7xIaoXo5sv9678OSK/JWg
# J9RdYuOJImytLrcPQQcdAgMBAAGjggFJMIIBRTAdBgNVHQ4EFgQUdQ5FIf+wH+tD
# 9t4PSXlXFDvToYgwHwYDVR0jBBgwFoAUn6cVXQBeYl2D9OXSZacbUzUZ6XIwXwYD
# VR0fBFgwVjBUoFKgUIZOaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9j
# cmwvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3JsMGwG
# CCsGAQUFBwEBBGAwXjBcBggrBgEFBQcwAoZQaHR0cDovL3d3dy5taWNyb3NvZnQu
# Y29tL3BraW9wcy9jZXJ0cy9NaWNyb3NvZnQlMjBUaW1lLVN0YW1wJTIwUENBJTIw
# MjAxMCgxKS5jcnQwDAYDVR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcD
# CDAOBgNVHQ8BAf8EBAMCB4AwDQYJKoZIhvcNAQELBQADggIBANkw+viBWbDB/gYw
# Hll8dKvfi6G6DrLO7gdRP4lYxmrP26EtkGhfkI+N0onPABW9ig24uZLT72UDlLvi
# u8qp3+72+nzxUaTpTuAxx5q12qkqVtVF2fZl+sxykjjM5zoG25ivMlXhwSzViZf3
# m6IDFoQPfjDTYGd+49lcDR52wMFt3iLEVTxf/UnQN8hSTVgVg86ubCYjaTXq7pNw
# o7RilGXBN0Kr287R4QgRHVIuZA0HNf2HZxwK+2B6Q5oGghDdlFqLwOzV/7BwoI/M
# PioNffE2C8sWIqgDplIb1L/I6sZqJIYh4PLk31VC6pM2OvK4DOO9/lbwBCnfWFXU
# ZtQM6RtR137OQlYpfgWbN543nYQRvKShZwnlX0zgM8Y3nGkWpfL1o7T51HRRRha6
# p4uEPJGdV5lxMS7TGCaj6lAdq4VUBKxU5EynxMXx2l6x362qSRDxU28jbSg5+dN8
# v7tmBQx/uo1XSWXRajmeWvUIm9rVt+TYdzkFjUz2x3duUGR7PK8k+fiPRt846sJh
# PBiw2yOJGX9ZbXw06mLCpyLAWVQ2q1YJEzML2vzhhpQxDzYHLCTjx3i4GiflkDyl
# ddLuPAlOMmPlRJ5GX2+NP3w8NnIIU7Z4VI4V0N1/pYGj9ZlQDaEZnSr4nuPXjR9t
# cJ85QibSPbcdoBXRyQNL+eYL+gXWMIIHcTCCBVmgAwIBAgITMwAAABXF52ueAptJ
# mQAAAAAAFTANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgT
# Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNh
# dGUgQXV0aG9yaXR5IDIwMTAwHhcNMjEwOTMwMTgyMjI1WhcNMzAwOTMwMTgzMjI1
# WjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
# UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQD
# Ex1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDCCAiIwDQYJKoZIhvcNAQEB
# BQADggIPADCCAgoCggIBAOThpkzntHIhC3miy9ckeb0O1YLT/e6cBwfSqWxOdcjK
# NVf2AX9sSuDivbk+F2Az/1xPx2b3lVNxWuJ+Slr+uDZnhUYjDLWNE893MsAQGOhg
# fWpSg0S3po5GawcU88V29YZQ3MFEyHFcUTE3oAo4bo3t1w/YJlN8OWECesSq/XJp
# rx2rrPY2vjUmZNqYO7oaezOtgFt+jBAcnVL+tuhiJdxqD89d9P6OU8/W7IVWTe/d
# vI2k45GPsjksUZzpcGkNyjYtcI4xyDUoveO0hyTD4MmPfrVUj9z6BVWYbWg7mka9
# 7aSueik3rMvrg0XnRm7KMtXAhjBcTyziYrLNueKNiOSWrAFKu75xqRdbZ2De+JKR
# Hh09/SDPc31BmkZ1zcRfNN0Sidb9pSB9fvzZnkXftnIv231fgLrbqn427DZM9itu
# qBJR6L8FA6PRc6ZNN3SUHDSCD/AQ8rdHGO2n6Jl8P0zbr17C89XYcz1DTsEzOUyO
# ArxCaC4Q6oRRRuLRvWoYWmEBc8pnol7XKHYC4jMYctenIPDC+hIK12NvDMk2ZItb
# oKaDIV1fMHSRlJTYuVD5C4lh8zYGNRiER9vcG9H9stQcxWv2XFJRXRLbJbqvUAV6
# bMURHXLvjflSxIUXk8A8FdsaN8cIFRg/eKtFtvUeh17aj54WcmnGrnu3tz5q4i6t
# AgMBAAGjggHdMIIB2TASBgkrBgEEAYI3FQEEBQIDAQABMCMGCSsGAQQBgjcVAgQW
# BBQqp1L+ZMSavoKRPEY1Kc8Q/y8E7jAdBgNVHQ4EFgQUn6cVXQBeYl2D9OXSZacb
# UzUZ6XIwXAYDVR0gBFUwUzBRBgwrBgEEAYI3TIN9AQEwQTA/BggrBgEFBQcCARYz
# aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9Eb2NzL1JlcG9zaXRvcnku
# aHRtMBMGA1UdJQQMMAoGCCsGAQUFBwMIMBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIA
# QwBBMAsGA1UdDwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFNX2
# VsuP6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwu
# bWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8yMDEw
# LTA2LTIzLmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKGPmh0dHA6Ly93
# d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYt
# MjMuY3J0MA0GCSqGSIb3DQEBCwUAA4ICAQCdVX38Kq3hLB9nATEkW+Geckv8qW/q
# XBS2Pk5HZHixBpOXPTEztTnXwnE2P9pkbHzQdTltuw8x5MKP+2zRoZQYIu7pZmc6
# U03dmLq2HnjYNi6cqYJWAAOwBb6J6Gngugnue99qb74py27YP0h1AdkY3m2CDPVt
# I1TkeFN1JFe53Z/zjj3G82jfZfakVqr3lbYoVSfQJL1AoL8ZthISEV09J+BAljis
# 9/kpicO8F7BUhUKz/AyeixmJ5/ALaoHCgRlCGVJ1ijbCHcNhcy4sa3tuPywJeBTp
# kbKpW99Jo3QMvOyRgNI95ko+ZjtPu4b6MhrZlvSP9pEB9s7GdP32THJvEKt1MMU0
# sHrYUP4KWN1APMdUbZ1jdEgssU5HLcEUBHG/ZPkkvnNtyo4JvbMBV0lUZNlz138e
# W0QBjloZkWsNn6Qo3GcZKCS6OEuabvshVGtqRRFHqfG3rsjoiV5PndLQTHa1V1QJ
# sWkBRH58oWFsc/4Ku+xBZj1p/cvBQUl+fpO+y/g75LcVv7TOPqUxUYS8vwLBgqJ7
# Fx0ViY1w/ue10CgaiQuPNtq6TPmb/wrpNPgkNWcr4A245oyZ1uEi6vAnQj0llOZ0
# dFtq0Z4+7X6gMTN9vMvpe784cETRkPHIqzqKOghif9lwY1NNje6CbaUFEMFxBmoQ
# tB1VM1izoXBm8qGCA00wggI1AgEBMIH5oYHRpIHOMIHLMQswCQYDVQQGEwJVUzET
# MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
# TWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmlj
# YSBPcGVyYXRpb25zMScwJQYDVQQLEx5uU2hpZWxkIFRTUyBFU046QTkzNS0wM0Uw
# LUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2WiIwoB
# ATAHBgUrDgMCGgMVAO+7yGSEQy3lnwt15+WzvPUtVTymoIGDMIGApH4wfDELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9z
# b2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwDQYJKoZIhvcNAQELBQACBQDr4NhNMCIY
# DzIwMjUwNTI4MDAzMzE3WhgPMjAyNTA1MjkwMDMzMTdaMHQwOgYKKwYBBAGEWQoE
# ATEsMCowCgIFAOvg2E0CAQAwBwIBAAICAKcwBwIBAAICE9QwCgIFAOviKc0CAQAw
# NgYKKwYBBAGEWQoEAjEoMCYwDAYKKwYBBAGEWQoDAqAKMAgCAQACAwehIKEKMAgC
# AQACAwGGoDANBgkqhkiG9w0BAQsFAAOCAQEASxfXN88LIfirSsDRN7ZI6NeQXlk/
# gejSCJtJ1xoattz5iOWeF0GToujcNAbvwng70dZUsoaUHN7flmo8BTTRqrf/FRtX
# CHJ8odqC9IE4xavp3+h4bqV9VGJk+1tKtLJyoB79cfy0SNV+h+EvoWalBCgdA71Q
# ooQaLcyAT47efccjTYSqJDdZ1mP0+E+dbjsIktgc48fVKBUpDrBipEEsp1lKrDXB
# 01gRZOwHPnn6UL6ij2Y/SmYvPP8dvcEX3KTuZTtREtVB/J53fzDUsw1T3vKuykyt
# RhJ18WPvA+aGOW7bOT21EEpcSthKsXlMfrv90U9soqHaUjWIP+9gX+viIzGCBA0w
# ggQJAgEBMIGTMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
# DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
# JjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwAhMzAAACDLlk
# 4zWc7PSuAAEAAAIMMA0GCWCGSAFlAwQCAQUAoIIBSjAaBgkqhkiG9w0BCQMxDQYL
# KoZIhvcNAQkQAQQwLwYJKoZIhvcNAQkEMSIEIMgxz2w53wRwDozjWcXYQ+e73AxH
# cDjh7s2Zk18PdHHaMIH6BgsqhkiG9w0BCRACLzGB6jCB5zCB5DCBvQQg1SjXtwUx
# k3jowjk18gCD1THlw7nEz2Ket7muK45nwi0wgZgwgYCkfjB8MQswCQYDVQQGEwJV
# UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
# ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGlt
# ZS1TdGFtcCBQQ0EgMjAxMAITMwAAAgy5ZOM1nOz0rgABAAACDDAiBCCVSfGjqNgy
# zwO1daMLeZq64At23AUo1RWqMCtzwbQz4jANBgkqhkiG9w0BAQsFAASCAgCpUwyK
# IfaUYr2BA0h0o+ggAiCByuoElh1GLILJ71r8f+WjQNMRQ2DtJMcJo5S6UGkFIdBs
# XcGrcvgheeUMUMjdVsXCZwLF+b0uVUuHc4IyrIh2JKiqoElA0/WgSsYWKlpqyvSo
# 4CM0tixkmbINJFdeQxiLkqMf8Br1UjS2M/B/dsO1yo+XpC8ZSiukCPr1dfFI+LwB
# 1RzxSwxcfSUOg2bRq0cmc2wsZss7T5P6SkqCx7sx1OqupD8W9XgLtlXUXObqWGbn
# mFTFxDLhO9hi5DLR74Ar8X7m1xiYaPTYIqQaf+h8pmbD+r2EYqb9gSG1j8ce2vqD
# 9VLxKi2KYiPNPgSapbibZYAwauCa4bZbx6oFaHPJcR6ILkKifuFvnw7Ro5NwDC3n
# tlG+TnEeHGndXnCA9FJQYqVbZsWzGxIW6k5Ggku4PRGSzjPy2fthMQjOr78M/OGD
# jBwW1yoA2foA5BWXYDd0HDd90IbPJBeXdRDvE+vJ7PYmpVWDfMZO4z/IKp60Q1gO
# Tggw+Uu5FNzwGKrWRnZsd4SP8mgxhFd2GwjVbWyoymUtM6ZAWjLBUTZ9ZcbUEDIM
# 9yQl1+eXeWb1gr2yprc7bfpR/DHATdgC4ppg8P+sWe34uh7OiMY+6GBib/pnPXuu
# S127xSrbdW9PURbpbXlJJRUakTdAcSNu6dG2yg==
# SIG # End signature block
